
/*++
*******************************************************************************
* Copyright (c) 1990-98 Digi International Inc., All Rights Reserved				*
* 																										*
* This software contains proprietary and confidential information of Digi		*
* International Inc.  By accepting transfer of this copy, Recipient agrees		*
* to retain this software in confidence, to prevent disclosure to others,		*
* and to make no use of this software other than that for which it was			*
* delivered.  This is an unpublished copyrighted work of Digi International	*
* Inc.  Except as permitted by federal law, 17 USC 117, copying is strictly	*
* prohibited.																						*
* 																										*
* Restricted Rights Legend																		*
*																										*
* Use, duplication, or disclosure by the Government is subject to					*
* restrictions set forth in sub-paragraph (c)(1)(ii) of The Rights in			*
* Technical Data and Computer Software clause at DFARS 252.227-7031 or			*
* subparagraphs (c)(1) and (2) of the Commercial Computer Software -				*
* Restricted Rights at 48 CFR 52.227-19, as applicable.								*
*																										*
* Digi International Inc. 11001 Bren Road East, Minnetonka, MN 55343				*
*																										*
*******************************************************************************

Module Name:

   dxblog.h

Abstract:

   Routines to write messages to the event log.

Author:

   Michael Zarns

--*/

#ifndef DXBLOG_H
#define DXBLOG_H

VOID
dxbLogResourceConflict(
	IN PUNICODE_STRING AdapterName );

VOID
dxbLogAdapterNotFound(
	IN PUNICODE_STRING AdapterName );

VOID
dxbLogAdapterResetFailed(
	IN PUNICODE_STRING AdapterName );

VOID
dxbLogMemoryFailure(
	IN PUNICODE_STRING AdapterName );

VOID
dxbLogFileNotFound(
	IN PUNICODE_STRING Filename );

VOID
dxbLogBiosFailed(
	IN PUNICODE_STRING AdapterName );

VOID
dxbLogPostFailed(
	IN PUNICODE_STRING AdapterName );

VOID
dxbLogFepFailed(
	IN PUNICODE_STRING AdapterName );

VOID
dxbLogBadFepImage(
	IN PUNICODE_STRING AdapterName,
	IN PUNICODE_STRING FileName,
	IN USHORT          FileType );

VOID
dxbLogPostErrors(
	IN PUNICODE_STRING AdapterName );

#endif
